==> qmltube_0.6.6.tar.gz: qmltube-0.6.6/controller.cpp <==
#include "controller.h"
#include <QDeclarativeView>
#include <QDebug>
#include <QFile>
#include <QDir>
#include <QApplication>
#include <QClipboard>
#include <QtSql/QSqlDatabase>
#include <QtSql/QSqlQuery>
#include <QtSql/QSqlRecord>
#include <QVariant>
#include <QString>
#include <QMap>
#include <QTranslator>
#include <QProcess>

#ifdef Q_WS_MAEMO_5
#include <QtDBus/QDBusConnection>
#include <QtDBus/QDBusMessage>
#include <QtDBus/QDBusInterface>
#endif

Controller::Controller(QObject *parent) :
    QObject(parent) {
    converter = new QProcess(this);
    connect(converter, SIGNAL(started()), this, SIGNAL(conversionStarted()));
    connect(converter, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(conversionFinished(int, QProcess::ExitStatus)));    
}

void Controller::setView(QmlApplicationViewer *view) {
    m_view = view;
}

void Controller::toggleState() {
    if (!m_view->isFullScreen()) {
        m_view->showFullScreen();
    }
    else {
        m_view->showMaximized();
    }
}

QString Controller::getLanguage() const {
    QString langCode = "en";

    QSqlDatabase db;
    db = QSqlDatabase::addDatabase("QSQLITE");
    db.setDatabaseName("/home/user/.config/cutetube/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite");
    db.open();

    QSqlQuery query("select value from settings where setting = 'language'");
    QSqlRecord record = query.record();
    if (record.count() > 0) {
        while (query.next()) {
            langCode = query.value(0).toString();
        }
    }
    //    qDebug() << langCode;
    db.close();
    return langCode;
}

void Controller::setOrientation(const QString &orient) {
    if (orient == "automatic") {
        m_view->setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
    }
    else if (orient == "landscape") {
        m_view->setOrientation(QmlApplicationViewer::ScreenOrientationLockLandscape);
    }
    else if (orient == "portrait") {
        m_view->setOrientation(QmlApplicationViewer::ScreenOrientationLockPortrait);
    }
}

void Controller::minimize() {
#ifdef Q_WS_MAEMO_5
    QDBusConnection bus = QDBusConnection::sessionBus();

    QDBusMessage message = QDBusMessage::createSignal("/", "com.nokia.hildon_desktop", "exit_app_view");
    bus.send(message);
#endif
}

void Controller::setMediaPlayer(const QString &player) {
    mediaPlayer = player.toLower().replace(" ", "");
}

void Controller::getMediaPlayerFromDB() {
    QSqlDatabase db;
    db = QSqlDatabase::addDatabase("QSQLITE");
    db.setDatabaseName("/home/user/.config/cutetube/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite");
    db.open();

    QSqlQuery query("select value from settings where setting = 'mediaPlayer'");
    QSqlRecord record = query.record();
    QString player = "Media Player";
    if (record.count() > 0) {
        while (query.next()) {
            player = query.value(0).toString();
        }
        //        qDebug() << player;
    }
    setMediaPlayer(player);
    db.close();
}

QStringList Controller::getProxyFromDB() const {
    QSqlDatabase db;
    db = QSqlDatabase::addDatabase("QSQLITE");
    db.setDatabaseName("/home/user/.config/cutetube/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite");
    db.open();

    QSqlQuery query;
    query.exec("insert or ignore into settings values ('proxy', ':')");
    query.exec("select value from settings where setting = 'proxy'");
    QSqlRecord record = query.record();
    QStringList proxy;
    QString result;
    if (record.count() > 0) {
        while (query.next()) {
            result = query.value(0).toString();
            proxy = result.split(":");
        }
//        qDebug() << proxy;
    }
    else {
        proxy << "" << "";
    }
//    qDebug() << proxy;
    db.close();
    return proxy;
}

QStringList Controller::getInstalledMediaPlayers() const {
    QStringList playerList;
    playerList << "Media Player";
    if ((QFile::exists("/usr/bin/mplayer"))) {
        playerList << "MPlayer";
    }
    if ((QFile::exists("/opt/kmplayer/bin/kmplayer")) || (QFile::exists("/usr/bin/kmplayer"))) {
        playerList << "KMPlayer";
    }
    return playerList;
}

bool Controller::xTubeInstalled() {
    bool isInstalled = false;
    if (QFile::exists("/opt/usr/share/qmltube/qml/qmltube/scripts/xtube.js")) {
        isInstalled = true;
    }
    return isInstalled;
}

void Controller::playVideo(const QString &url) {
#ifdef Q_WS_MAEMO_5
    //    qDebug() << url;
    minimize();
    if (mediaPlayer == "mplayer") {
        QStringList args;
        args << "-cache" << "4096" << "-fs" << url;
        QProcess *player = new QProcess();
        connect(player, SIGNAL(finished(int, QProcess::ExitStatus)), player, SLOT(deleteLater()));
        player->start("/usr/bin/mplayer", args);
    }
    else {
        QDBusConnection bus = QDBusConnection::sessionBus();
        QDBusInterface dbus_iface("com.nokia." + mediaPlayer, "/com/nokia/" + mediaPlayer, "com.nokia." + mediaPlayer, bus);
        dbus_iface.call("mime_open", url);
    }
    emit playbackStarted();

#else
    QStringList args;
    args << "-cache" << "4096" << "-fs" << url;
    QProcess *player = new QProcess();
    connect(player, SIGNAL(finished(int, QProcess::ExitStatus)), player, SLOT(deleteLater()));
    player->start("/usr/bin/mplayer", args);
#endif
}

void Controller::deleteVideo(const QString &path) {
    if (QFile::exists(path)) {
        if (QFile::remove(path)) {
            emit alert(tr("Video deleted from device"));
        }
        else {
            emit alert(tr("Unable to delete video"));
        }
    }
    else {
        emit alert(tr("Video not found"));
    }
}

QString Controller::archiveFileExists(const QString &filePath, const QString &archivePath) const {
    QString result = "Not found";
    if (QFile::exists(filePath)) {
        result = "Unchanged";
    }
    else {
        QString newPath = archivePath;
        newPath.append(filePath.split("/").last());
        if (QFile::exists(newPath)) {
            result = newPath;
        }
    }
    return result;
}

bool Controller::pathExists(const QString &path) {
    QDir dir(path);
    return dir.exists();
}

void Controller::convertToAudio(const QString &input) {
    inputFile = input;
    QString ffmpeg = "/usr/bin/ffmpeg";
    QStringList args;
    outputFile = input;
    outputFile.replace(".mp4", ".m4a");
    args << "-i" << inputFile << "-acodec" << "copy" << "-y" << "-vn" << outputFile;

    converter->start(ffmpeg, args);
}

void Controller::conversionFinished(int exitCode, QProcess::ExitStatus exitStatus) {

    if ((exitCode == 0) && (exitStatus == QProcess::NormalExit)) {
        QFile output(outputFile);
        if (output.size() > 0) {
            emit conversionCompleted();
            QFile::remove(inputFile);
        }
        else {
            emit conversionFailed();
            QFile::remove(outputFile);
        }
    }
    else {
        emit conversionFailed();
    }
}

void Controller::copyToClipboard(const QString &url) {
    QApplication::clipboard()->setText(url);
    emit alert(tr("Copied to clipboard"));
}

==> qmltube_0.7.1.tar.gz: qmltube-0.7.1/controller.cpp <==
#include "controller.h"
#include <QDeclarativeView>
#include <QDebug>
#include <QFile>
#include <QDir>
#include <QApplication>
#include <QClipboard>
#include <QtSql/QSqlDatabase>
#include <QtSql/QSqlQuery>
#include <QtSql/QSqlRecord>
#include <QVariant>
#include <QString>
#include <QMap>
#include <QTranslator>
#include <QProcess>

#ifdef Q_WS_MAEMO_5
#include <QtDBus/QDBusConnection>
#include <QtDBus/QDBusMessage>
#include <QtDBus/QDBusInterface>
#endif

Controller::Controller(QObject *parent) :
    QObject(parent) {
    converter = new QProcess(this);
    connect(converter, SIGNAL(started()), this, SIGNAL(conversionStarted()));
    connect(converter, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(conversionFinished(int, QProcess::ExitStatus)));    
}

void Controller::setView(QmlApplicationViewer *view) {
    m_view = view;
}

void Controller::toggleState() {
    if (!m_view->isFullScreen()) {
        m_view->showFullScreen();
    }
    else {
        m_view->showMaximized();
    }
}

QString Controller::getLanguage() const {
    QString langCode = "en";

    QSqlDatabase db;
    db = QSqlDatabase::addDatabase("QSQLITE");
    db.setDatabaseName("/home/user/.config/cutetube/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite");
    db.open();

    QSqlQuery query("select value from settings where setting = 'language'");
    QSqlRecord record = query.record();
    if (record.count() > 0) {
        while (query.next()) {
            langCode = query.value(0).toString();
        }
    }
    //    qDebug() << langCode;
    db.close();
    return langCode;
}

void Controller::setOrientation(const QString &orient) {
    if (orient == "automatic") {
        m_view->setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
    }
    else if (orient == "landscape") {
        m_view->setOrientation(QmlApplicationViewer::ScreenOrientationLockLandscape);
    }
    else if (orient == "portrait") {
        m_view->setOrientation(QmlApplicationViewer::ScreenOrientationLockPortrait);
    }
}

void Controller::minimize() {
#ifdef Q_WS_MAEMO_5
    QDBusConnection bus = QDBusConnection::sessionBus();

    QDBusMessage message = QDBusMessage::createSignal("/", "com.nokia.hildon_desktop", "exit_app_view");
    bus.send(message);
#endif
}

void Controller::setMediaPlayer(const QString &player) {
    mediaPlayer = player.toLower().replace(" ", "");
}

bool Controller::widgetInstalled() const {
    bool isInstalled = false;

#ifdef Q_WS_MAEMO_5
    if (QFile::exists("/usr/share/hildon-desktop/qmltube-widget")) {
        isInstalled = true;
    }
#endif

    return isInstalled;
}

void Controller::getMediaPlayerFromDB() {
    QSqlDatabase db;
    db = QSqlDatabase::addDatabase("QSQLITE");
    db.setDatabaseName("/home/user/.config/cutetube/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite");
    db.open();

    QSqlQuery query("select value from settings where setting = 'mediaPlayer'");
    QSqlRecord record = query.record();
    QString player = "Media Player";
    if (record.count() > 0) {
        while (query.next()) {
            player = query.value(0).toString();
        }
        //        qDebug() << player;
    }
    setMediaPlayer(player);
    db.close();
}

QStringList Controller::getProxyFromDB() const {
    QSqlDatabase db;
    db = QSqlDatabase::addDatabase("QSQLITE");
    db.setDatabaseName("/home/user/.config/cutetube/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite");
    db.open();

    QSqlQuery query;
    query.exec("insert or ignore into settings values ('proxy', ':')");
    query.exec("select value from settings where setting = 'proxy'");
    QSqlRecord record = query.record();
    QStringList proxy;
    QString result;
    if (record.count() > 0) {
        while (query.next()) {
            result = query.value(0).toString();
            proxy = result.split(":");
        }
        //        qDebug() << proxy;
    }
    else {
        proxy << "" << "";
    }
    //    qDebug() << proxy;
    db.close();
    return proxy;
}

QStringList Controller::getInstalledMediaPlayers() const {
    QStringList playerList;
    playerList << "Media Player";
    if ((QFile::exists("/usr/bin/mplayer"))) {
        playerList << "MPlayer";
    }
    if ((QFile::exists("/opt/kmplayer/bin/kmplayer")) || (QFile::exists("/usr/bin/kmplayer"))) {
        playerList << "KMPlayer";
    }
    return playerList;
}

void Controller::playVideo(const QString &url) {
#ifdef Q_WS_MAEMO_5
    //    qDebug() << url;
    minimize();
    if (mediaPlayer == "mplayer") {
        QStringList args;
        args << "-cache" << "4096" << "-fs" << url;
        QProcess *player = new QProcess();
        connect(player, SIGNAL(finished(int, QProcess::ExitStatus)), player, SLOT(deleteLater()));
        player->start("/usr/bin/mplayer", args);
    }
    else {
        QDBusConnection bus = QDBusConnection::sessionBus();
        QDBusInterface dbus_iface("com.nokia." + mediaPlayer, "/com/nokia/" + mediaPlayer, "com.nokia." + mediaPlayer, bus);
        dbus_iface.call("mime_open", url);
    }
    emit playbackStarted();

#else
    QStringList args;
    args << "-cache" << "4096" << "-fs" << url;
    QProcess *player = new QProcess();
    connect(player, SIGNAL(finished(int, QProcess::ExitStatus)), player, SLOT(deleteLater()));
    player->start("/usr/bin/mplayer", args);
#endif
}

void Controller::deleteVideo(const QString &path) {
    if (QFile::exists(path)) {
        if (QFile::remove(path)) {
            emit alert(tr("Video deleted from device"));
        }
        else {
            emit alert(tr("Unable to delete video"));
        }
    }
    else {
        emit alert(tr("Video not found"));
    }
}

QString Controller::archiveFileExists(const QString &filePath, const QString &archivePath) const {
    QString result = "Not found";
    if (QFile::exists(filePath)) {
        result = "Unchanged";
    }
    else {
        QString newPath = archivePath;
        newPath.append(filePath.split("/").last());
        if (QFile::exists(newPath)) {
            result = newPath;
        }
    }
    return result;
}

bool Controller::pathExists(const QString &path) {
    QDir dir(path);
    return dir.exists();
}

void Controller::convertToAudio(const QString &input) {
    inputFile = input;
    QString ffmpeg = "/usr/bin/ffmpeg";
    QStringList args;
    outputFile = input;
    outputFile.replace(".mp4", ".m4a");
    args << "-i" << inputFile << "-acodec" << "copy" << "-y" << "-vn" << outputFile;

    converter->start(ffmpeg, args);
}

void Controller::conversionFinished(int exitCode, QProcess::ExitStatus exitStatus) {

    if ((exitCode == 0) && (exitStatus == QProcess::NormalExit)) {
        QFile output(outputFile);
        if (output.size() > 0) {
            emit conversionCompleted();
            QFile::remove(inputFile);
        }
        else {
            emit conversionFailed();
            QFile::remove(outputFile);
        }
    }
    else {
        emit conversionFailed();
    }
}

void Controller::copyToClipboard(const QString &url) {
    QApplication::clipboard()->setText(url);
    emit alert(tr("Copied to clipboard"));
}
